← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~hjd/widelands/adding-barriers-bug-787508 into lp:widelands

 

Hans Joachim Desserud has proposed merging lp:~hjd/widelands/adding-barriers-bug-787508 into lp:widelands.

Requested reviews:
  Widelands Developers (widelands-dev)

For more details, see:
https://code.launchpad.net/~hjd/widelands/adding-barriers-bug-787508/+merge/70653

When strongholds were removed, this left some of the missions without any medium-sized military buildings at all. I think it would be better to replace the strongholds with barriers than just remove them. See also my comment on https://code.launchpad.net/~lcsand/widelands/bug-787508/+merge/62722
-- 
https://code.launchpad.net/~hjd/widelands/adding-barriers-bug-787508/+merge/70653
Your team Widelands Developers is requested to review the proposed merge of lp:~hjd/widelands/adding-barriers-bug-787508 into lp:widelands.
=== modified file 'campaigns/emp02.wmf/scripting/starting_conditions.lua'
--- campaigns/emp02.wmf/scripting/starting_conditions.lua	2011-05-27 18:09:33 +0000
+++ campaigns/emp02.wmf/scripting/starting_conditions.lua	2011-08-06 16:51:07 +0000
@@ -73,6 +73,7 @@
 p2:forbid_buildings("all")
 p2:allow_buildings{
    "bakery",
+   "barrier",
    "farm",
    "fernery",
    "fishers_hut",

=== modified file 'campaigns/t02.wmf/scripting/mission_thread.lua'
--- campaigns/t02.wmf/scripting/mission_thread_texts.lua	2011-05-27 18:09:33 +0000
+++ campaigns/t02.wmf/scripting/mission_thread_texts.lua	2011-08-06 16:51:07 +0000
@@ -82,7 +82,7 @@
    name = "mission quarry",
    title =_"Expand north-east and build a quarry",
    body = obj_text(_"Expand north-east to the stones", _
-[[Build military buildings (like sentries) to expand your
+[[Build military buildings (like sentries or barriers) to expand your
 territory. Get to the rocks northeast from you and build a quarry there.]]
    ),
 }

=== modified file 'campaigns/t02.wmf/scripting/starting_conditions.lua'
--- campaigns/t02.wmf/scripting/starting_conditions.lua	2011-05-27 18:09:33 +0000
+++ campaigns/t02.wmf/scripting/starting_conditions.lua	2011-08-06 16:51:07 +0000
@@ -8,7 +8,8 @@
    "lumberjacks_hut",
    "quarry", 
    "rangers_hut", 
-   "sentry"
+   "sentry",
+   "barrier"
 }
 
 -- Place hq and fill it with wares


Follow ups
--- campaigns/t02.wmf/scripting/mission_thread.lua	2011-05-27 18:09:33 +0000
+++ campaigns/t02.wmf/scripting/mission_thread.lua	2011-08-06 16:51:07 +0000
@@ -183,10 +183,10 @@
 function build_materials_thread()
    local plr = wl.Game().players[1]
 
    -- Wait for a sentry to be build
    while true do
-      local rv = plr:get_buildings{"sentry"}
-      if #rv.sentry > 0 then
+      local rv = plr:get_buildings{"sentry", "barrier"}
+      if #rv.sentry + #rv.barrier > 0 then
          break
       end
       sleep(5421)
@@ -183,10 +183,10 @@
    local plr = wl.Game().players[1]
 
-   -- Wait for a sentry to be build
+   -- Wait for a barrier or sentry to be build
    while true do

=== modified file 'campaigns/t02.wmf/scripting/mission_thread_texts.lua'